{ pkgs, osConfig, ... }:
let
  withCuda = if (osConfig.system.name == "gunter") then true else false;
in
{
  imports = [
    ./zoom.nix
    ./tacl.nix
  ];
  home.packages = with pkgs; [
    # CLI utils
    act
    age
    aichat
    bat
    bzip2
    chromium
    croc
    devenv
    distrobox
    dust
    easyeffects
    eza
    fd
    ffmpeg
    file
    fzf
    glib
    grimblast
    ijq
    incus
    jellyfin-media-player
    jujutsu
    jq
    kitty
    kubectl
    lazygit
    lf
    ncdu
    nvd
    nurl
    nwg-look
    most
    pinentry
    pre-commit
    pulseaudio
    pulsemixer
    rbw
    restic
    ripgrep
    sidequest
    sops
    sshfs
    step-cli
    tea
    tldr
    tokei
    unzip
    wtype

    # Non-CLI stuff
    alacritty
    discord
    feh
    krita
    mpv
    mumble
    pamixer
    rofi-rbw-wayland
    spicetify-cli
    spotify
    virt-manager
    vmware-horizon-client
    yt-dlp

    # k8s tools
    cilium-cli
    cmctl
    k9s
    krew
    kubernetes-helm
    talosctl

    # Go stuff
    go
    delve
    gopls

    # js/ts
    nodejs
    nodePackages.pnpm
    typescript

    # Py stuff
    (python312.withPackages (
      p: with p; [
        requests
        ipython
      ]
    ))
    poetry
    ruff

    # rust stuff
    rustc
    cargo
    rust-analyzer

    # Homemade shit
    ghettoptt
    huecli
    nixprstatus

    # Stuff with overrides
    # Btop
    (btop.override { cudaSupport = withCuda; })
    # PrismLauncher
    prismlauncher

    (pkgs.linkFarm "logcli" [
      {
        name = "bin/logcli";
        path = "${pkgs.grafana-loki}/bin/logcli";
      }
    ])
    (lutris.override {
      extraLibraries = pkgs: [
        nspr
        xorg.libXdamage
      ];
    })
  ];
}
